@@ -1,4 +1,4 @@
-from urtools.json import load_json, load_dict, load_list, load_list_of_dicts
+from urtools.json import load_json, load_dict, load_list, load_list_of_dicts, dump_json
 from urtools.regex import strings2re
 from urtools.string import findall_str, modify_str, partition_n
 from urtools.type import issubtype, is_nonstr_iter
